@@ -218,10 +218,17 @@ class CommonBrowserView(BrowserView):
                 lead = None
             
         if lead is not None:
+            canCrop = self.checkPermission(item, "Modify portal content") and scale == 'crop'
+            crop = ""
+            
+            if canCrop:
+                cropLink = "%s/@@croppingeditor"%lead
+                crop = '<div class="cropButton" onclick="window.location = \'%s\'; return false;">Crop</div>'%cropLink
+            
             if hasattr(item, 'getURL'):
-                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />%(crop)s'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title, 'crop':crop}
             else:
-                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title()}
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />%(crop)s'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title(), 'crop':crop}
         else:
             return ""
 
